@@ -28,3 +28,11 @@ class InvalidCameraError(ValueError):
     def __init__(self, message=CAMERA_ERROR_MESSAGE):
         """Empty init."""
         ValueError.__init__(self, message)
+
+
+class DeprecationError(RuntimeError):
+    """Used for depreciated methods and functions."""
+
+    def __init__(self, message='This feature has been depreciated'):
+        """Empty init."""
+        RuntimeError.__init__(self, message)
